<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0" xmlns:hl7="urn:hl7-org:v3"
    exclude-result-prefixes="#all" xmlns:File="java:java.io.File" xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
    <xsl:output method="html" indent="yes" version="4.01" encoding="UTF-8" doctype-public="-//W3C//DTD HTML 4.01//EN"
        doctype-system="http://www.w3.org/TR/html4/strict.dtd"/>
    <xsl:template match="/">
        <html>
            <head>
                <script type="text/javascript">
                    function toggle(toggled,toggler) {
                    if (document.getElementById) {
                    var currentStyle = document.getElementById(toggled).style;
                    var togglerStyle = document.getElementById(toggler).style;
                    if (currentStyle.display == "block"){
                    currentStyle.display = "none";
                    togglerStyle.backgroundImage = "url(../css/plus.gif)";
                    } else {
                    currentStyle.display = "block";
                    togglerStyle.backgroundImage = "url(../css/minus.gif)";
                    }
                    return false;
                    } else {
                    return true;
                    }
                    }
                </script>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
                <title>Zorgtoepassingen</title>
                <link href="../css/documentation.css" type="text/css" rel="stylesheet"/>
            </head>
            <body>
                <h1>Overzicht Zorgtoepassingen</h1>
                <p/>
                <div class="paragraph">Documentatie vanuit het perspectief van de zorgtoepassingen..</div>
                <xsl:apply-templates/>
                <!--<xsl:call-template name="fileList"/>-->
            </body>
        </html>
    </xsl:template>
    <xsl:template match="zorgToepassing">
        <xsl:call-template name="headingToggle">
            <xsl:with-param name="label" select="./naam"/>
            <xsl:with-param name="heading" select="'h1'"/>
        </xsl:call-template>
    </xsl:template>
    <xsl:template match="omschrijving">
        <table class="values">
            <tr>
                <td class="value-label">Omschrijving</td>
                <td class="value">
                    <xsl:value-of select="."/>
                </td>
            </tr>
        </table>
    </xsl:template>
    <xsl:template match="naam">
        <table class="values">
            <tr>
                <td class="value-label">Naam</td>
                <td class="value">
                    <xsl:value-of select="."/>
                </td>
            </tr>
        </table>
    </xsl:template>
    <xsl:template match="documentatie">
        <table class="values">
            <tr>
                <td class="value-label">Documentatie</td>
                <td class="value">
                    <xsl:call-template name="fileList">
                        <xsl:with-param name="directory" select="@directory"/>
                    </xsl:call-template>
                </td>
            </tr>
        </table>
    </xsl:template>
    <xsl:template match="applicatieRol">
        <xsl:call-template name="section">
            <xsl:with-param name="label" select="'Applicatierol'"/>
        </xsl:call-template>
    </xsl:template>
    <xsl:template match="wsdl">
        <table class="values">
            <tr>
                <td class="value-label">
                    WSDL
                </td>
                <td>
                    <xsl:element name="a">
                        <xsl:attribute name="href">
                            
                            <xsl:value-of select="concat(@file,'.html')"/>
                        </xsl:attribute>
                        <xsl:value-of select="substring-after(@file,'wsdl/')"/>
                    </xsl:element>
                </td>
            </tr>
        </table>
    </xsl:template>
    <xsl:template name="fileList">
        <xsl:param name="directory"/>
        <xsl:variable name="dir" select="File:new(resolve-uri($directory))"/>
        <xsl:variable name="files" select="File:list($dir)"/>
        <table class="values">
            <xsl:for-each select="$files">
                <xsl:if test="not(starts-with(.,'.'))">
                    <xsl:variable name="file" select="File:new(resolve-uri(concat($directory,'/',.)))"/>
                    <xsl:choose>
                        <xsl:when test="File:isDirectory($file)">
<!--                            <xsl:call-template name="fileList">
                                <xsl:with-param name="directory" select="concat(resolve-uri($directory),'/',.)"/>
                            </xsl:call-template>-->
                        </xsl:when>
                        <xsl:when test="File:isFile($file)">
                            <tr>
                                <td>
                                    <xsl:element name="a">
                                        <xsl:attribute name="href">
                                            
                                            <xsl:value-of select="concat($directory,'/',.)"/>
                                        </xsl:attribute>
                                        <xsl:value-of select="."/>
                                    </xsl:element>
                                    
                                </td>
                            </tr>
                        </xsl:when>
                    </xsl:choose>
                    
                </xsl:if>
            </xsl:for-each>
        </table>
    </xsl:template>
    <!-- Template voor heading waarop een div volgt die opengeklikt kan worden -->
    <xsl:template name="headingToggle">
        <xsl:param name="label"/>
        <xsl:param name="heading"/>
        <xsl:variable name="id" select="generate-id()"/>
        <xsl:variable name="id-toggler" select="concat($id,'-toggler')"/>
        <xsl:element name="{$heading}">
            <xsl:attribute name="class" select="'toggler'"/>
            <xsl:attribute name="id" select="$id-toggler"/>
            <xsl:attribute name="onclick"
                select="concat('return toggle(&quot;',$id,'&quot;,&quot;',$id-toggler,'&quot;)')"/>
            <xsl:value-of select="$label"/>
        </xsl:element>
        <div class="level2">
            <xsl:element name="div">
                <xsl:attribute name="id" select="$id"/>
                <xsl:attribute name="class" select="'toggle'"/>
                <xsl:apply-templates/>
            </xsl:element>
        </div>
    </xsl:template>
    <xsl:template name="section">
        <xsl:param name="label"/>
        <xsl:param name="negationIndLabel" select="NIET"/>
        <table class="section">
            <tr>
                <td class="section-label">
                    <xsl:value-of select="$label"/>
                    <xsl:if test="./@negationInd='true'">
                        <div>
                            <xsl:value-of select="$negationIndLabel"/>
                        </div>
                    </xsl:if>
                </td>
                <td>
                    <xsl:apply-templates/>
                </td>
            </tr>
        </table>
    </xsl:template>
</xsl:stylesheet>
